==> qtjambi-qt3danimation-jre8-5.15.4-sources.jar: io/qt/qt3d/animation/QChannelMapping.java <==
package io.qt.qt3d.animation;


/**
 * <p>Allows to map the channels within the clip onto properties of objects in the application</p>
 * <p>Java wrapper for Qt class <a href="http://doc.qt.io/qt-5/qt3danimation-qchannelmapping.html">Qt3DAnimation::QChannelMapping</a></p>
 */
public class QChannelMapping extends io.qt.qt3d.animation.QAbstractChannelMapping
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QChannelMapping.class);
    

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qchannelmapping.html#channelName-prop">Qt3DAnimation::QChannelMapping::channelNameChanged(QString)</a></p>
     */
    @io.qt.QtPropertyNotify(name="channelName")
    public final Signal1<java.lang.String> channelNameChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qchannelmapping.html#property-prop">Qt3DAnimation::QChannelMapping::propertyChanged(QString)</a></p>
     */
    @io.qt.QtPropertyNotify(name="property")
    public final Signal1<java.lang.String> propertyChanged = new Signal1<>();

    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qchannelmapping.html#target-prop">Qt3DAnimation::QChannelMapping::targetChanged(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    @io.qt.QtPropertyNotify(name="target")
    public final Signal1<io.qt.qt3d.core.QNode> targetChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QChannelMapping(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QChannelMapping() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QChannelMapping(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QChannelMapping instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qchannelmapping.html#channelName-prop">Qt3DAnimation::QChannelMapping::channelName()const</a></p>
     */
    @io.qt.QtPropertyReader(name="channelName")
    @io.qt.QtUninvokable
    public final java.lang.String channelName(){
        return channelName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String channelName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qchannelmapping.html#property-prop">Qt3DAnimation::QChannelMapping::property()const</a></p>
     */
    @io.qt.QtPropertyReader(name="property")
    @io.qt.QtUninvokable
    public final java.lang.String property(){
        return property_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String property_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qchannelmapping.html#channelName-prop">Qt3DAnimation::QChannelMapping::setChannelName(QString)</a></p>
     */
    @io.qt.QtPropertyWriter(name="channelName")
    public final void setChannelName(java.lang.String channelName){
        setChannelName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), channelName);
    }
    
    private native void setChannelName_native_cref_QString(long __this__nativeId, java.lang.String channelName);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qchannelmapping.html#property-prop">Qt3DAnimation::QChannelMapping::setProperty(QString)</a></p>
     */
    @io.qt.QtPropertyWriter(name="property")
    public final void setProperty(java.lang.String property){
        setProperty_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), property);
    }
    
    private native void setProperty_native_cref_QString(long __this__nativeId, java.lang.String property);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qchannelmapping.html#target-prop">Qt3DAnimation::QChannelMapping::setTarget(Qt3DCore::QNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="target")
    @SuppressWarnings({"exports"})
    public final void setTarget(io.qt.qt3d.core.QNode target){
        setTarget_native_Qt3DCore_QNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(target));
    }
    
    private native void setTarget_native_Qt3DCore_QNode_ptr(long __this__nativeId, long target);
    
    /**
     * <p>See <a href="http://doc.qt.io/qt-5/qt3danimation-qchannelmapping.html#target-prop">Qt3DAnimation::QChannelMapping::target()const</a></p>
     */
    @io.qt.QtPropertyReader(name="target")
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNode target(){
        return target_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QNode target_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QChannelMapping(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QChannelMapping(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QChannelMapping instance, QDeclarativeConstructor constructor);
    
}

==> qtjambi-qt3danimation-jre8-6.2.1-sources.jar: io/qt/qt3d/animation/QChannelMapping.java <==
package io.qt.qt3d.animation;


/**
 * <p>Allows to map the channels within the clip onto properties of objects in the application</p>
 * <p>Java wrapper for Qt class <a href="https://doc.qt.io/qt/qt3danimation-qchannelmapping.html">Qt3DAnimation::QChannelMapping</a></p>
 */
public class QChannelMapping extends io.qt.qt3d.animation.QAbstractChannelMapping
{
    
    /**
     * This variable stores the meta-object for the class.
     */
    public static final io.qt.core.QMetaObject staticMetaObject = io.qt.core.QMetaObject.forType(QChannelMapping.class);
    

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qchannelmapping.html#channelName-prop">Qt3DAnimation::QChannelMapping::channelNameChanged(QString)</a></p>
     */
    @io.qt.QtPropertyNotify(name="channelName")
    public final Signal1<java.lang.String> channelNameChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qchannelmapping.html#property-prop">Qt3DAnimation::QChannelMapping::propertyChanged(QString)</a></p>
     */
    @io.qt.QtPropertyNotify(name="property")
    public final Signal1<java.lang.String> propertyChanged = new Signal1<>();

    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qchannelmapping.html#target-prop">Qt3DAnimation::QChannelMapping::targetChanged(Qt3DCore::QNode*)</a></p>
     */
    @SuppressWarnings({"exports"})
    @io.qt.QtPropertyNotify(name="target")
    public final Signal1<io.qt.qt3d.core.QNode> targetChanged = new Signal1<>();
    
    /**
     * <p>Overloaded constructor for {@link #QChannelMapping(io.qt.qt3d.core.QNode)}
     *  with <code>parent = null</code>.</p>
     */
    public QChannelMapping() {
        this((io.qt.qt3d.core.QNode)null);
    }
    
    @SuppressWarnings({"exports"})
    public QChannelMapping(io.qt.qt3d.core.QNode parent){
        super((QPrivateConstructor)null);
        initialize_native(this, parent);
    }
    
    private native static void initialize_native(QChannelMapping instance, io.qt.qt3d.core.QNode parent);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qchannelmapping.html#channelName-prop">Qt3DAnimation::QChannelMapping::channelName()const</a></p>
     */
    @io.qt.QtPropertyReader(name="channelName")
    @io.qt.QtUninvokable
    public final java.lang.String channelName(){
        return channelName_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String channelName_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qchannelmapping.html#property-prop">Qt3DAnimation::QChannelMapping::property()const</a></p>
     */
    @io.qt.QtPropertyReader(name="property")
    @io.qt.QtUninvokable
    public final java.lang.String property(){
        return property_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native java.lang.String property_native_constfct(long __this__nativeId);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qchannelmapping.html#channelName-prop">Qt3DAnimation::QChannelMapping::setChannelName(QString)</a></p>
     */
    @io.qt.QtPropertyWriter(name="channelName")
    public final void setChannelName(java.lang.String channelName){
        setChannelName_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), channelName);
    }
    
    private native void setChannelName_native_cref_QString(long __this__nativeId, java.lang.String channelName);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qchannelmapping.html#property-prop">Qt3DAnimation::QChannelMapping::setProperty(QString)</a></p>
     */
    @io.qt.QtPropertyWriter(name="property")
    public final void setProperty(java.lang.String property){
        setProperty_native_cref_QString(QtJambi_LibraryUtilities.internal.nativeId(this), property);
    }
    
    private native void setProperty_native_cref_QString(long __this__nativeId, java.lang.String property);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qchannelmapping.html#target-prop">Qt3DAnimation::QChannelMapping::setTarget(Qt3DCore::QNode*)</a></p>
     */
    @io.qt.QtPropertyWriter(name="target")
    @SuppressWarnings({"exports"})
    public final void setTarget(io.qt.qt3d.core.QNode target){
        setTarget_native_Qt3DCore_QNode_ptr(QtJambi_LibraryUtilities.internal.nativeId(this), QtJambi_LibraryUtilities.internal.checkedNativeId(target));
    }
    
    private native void setTarget_native_Qt3DCore_QNode_ptr(long __this__nativeId, long target);
    
    /**
     * <p>See <a href="https://doc.qt.io/qt/qt3danimation-qchannelmapping.html#target-prop">Qt3DAnimation::QChannelMapping::target()const</a></p>
     */
    @io.qt.QtPropertyReader(name="target")
    @SuppressWarnings({"exports"})
    @io.qt.QtUninvokable
    public final io.qt.qt3d.core.QNode target(){
        return target_native_constfct(QtJambi_LibraryUtilities.internal.nativeId(this));
    }
    
    @io.qt.QtUninvokable
    private native io.qt.qt3d.core.QNode target_native_constfct(long __this__nativeId);
    
    /**
     * Constructor for internal use only.
     * @param p expected to be <code>null</code>.
     */
    @io.qt.NativeAccess
    protected QChannelMapping(QPrivateConstructor p) { super(p); } 
    
    /**
     * Constructor for internal use only.
     * It is not allowed to call the declarative constructor from inside Java.
     */
    @io.qt.NativeAccess
    protected QChannelMapping(QDeclarativeConstructor constructor) {
        super((QPrivateConstructor)null);
        initialize_native(this, constructor);
    } 
    
    @io.qt.QtUninvokable
    private static native void initialize_native(QChannelMapping instance, QDeclarativeConstructor constructor);
    
}
